![PyCorrFit](https://raw.github.com/paulmueller/PyCorrFit/master/doc-src/Images/PyCorrFit_logo_dark.png)
=========

This repository contains the source code of PyCorrFit - a scientific tool for fitting
correlation curves on a logarithmic plot.

In current biomedical research, fluorescence correlation spectroscopy (FCS) is  applied
to characterize molecular dynamic processes in vitro and in living cells.  Commercial
FCS setups only permit data analysis that is limited to  a specific instrument by
the use of in-house file formats or a  finite number of implemented correlation
model functions. PyCorrFit is a general-purpose FCS evaluation software that,
amongst other formats, supports the established Zeiss ConfoCor3 ~.fcs  file format.
PyCorrFit comes with several built-in model functions, covering a wide range of
applications in standard confocal FCS. In addition, it contains equations dealing
with different excitation geometries like total internal reflection (TIR). For more
information, visit the official homepage at http://pycorrfit.craban.de.


- [Download the latest version](https://github.com/paulmueller/PyCorrFit/releases)  
- [Documentation](https://github.com/paulmueller/PyCorrFit/raw/master/PyCorrFit_doc.pdf)
- [Run PyCorrFit from source](https://github.com/paulmueller/PyCorrFit/wiki/Running-PyCorrFit-from-source)
- [Write model functions](https://github.com/paulmueller/PyCorrFit/wiki/Writing-model-functions)
- [Need help?](https://github.com/paulmueller/PyCorrFit/wiki/Creating-a-new-issue)
